@@ -1,7 +1,7 @@
-/* SCCS @(#)free_tree.c	1.2 02/08/98 */
 /*
 ** free up all of the memory associated with a tree
 */
+#include "rpart.h"
 #include "node.h"
 #include "rpartS.h"
 #include "rpartproto.h"
