@@ -1,4 +1,3 @@
-/* SCCS @(#)rpartexp2.c	1.1 07/05/01  */
 /*
 **   Cut down a list of death times, to avoid ones that differ by
 **    very, very little.
@@ -11,7 +10,7 @@
 #include "rpart.h"
 #include "rpartproto.h"
 
-void rpartexp2(Sint *n2, double *y, double *eps, long *keep) {
+void rpartexp2(Sint *n2, double *y, double *eps, int *keep) {
     int n;
     double delta;
     int i, j;
