@@ -1,5 +1,4 @@
 /*
-**  SCCS  @(#)s_xpred.c	1.16 06/06/01
 ** An S interface to "cross validated predictions"
 **    99% of this routine is a copy of s_to_rp and rpart.c
 */
@@ -35,7 +34,7 @@ void s_xpred(Sint *sn, 	   Sint *nvarx,   Sint *ncat,    Sint *method,
 	rp.num_y  = *ny;
 	}
     else {
-	*error = "Invalid value for 'method'";
+	*error = _("invalid value for 'method'");
 	*sn = -1; 
 	return;
 	}
